# Supported Datasets


```@eval
using SpeechDatasets, JSON, Markdown
corpora_infos = JSON.parsefile(SpeechDatasets.corpora_file)

function write_corpora_docs(io::IO)
    for corpus in corpora_infos
        fields = keys(corpus)
        println(io, "## $(corpus["name"])")

        if "license" in fields
            license = replace(corpus["license"], "-" => "--") # dash are escaped
            color = license=="proprietary" ? "red" : "lightblue"
            license_badge = "https://img.shields.io/badge/License-$license-$color"
            println(io, "![License]($license_badge)")
        end

        if "lang" in fields
            languages = corpus["lang"] isa String ? [corpus["lang"]] : corpus["lang"]
            for lang in languages
                lang_badge = "https://img.shields.io/badge/Lang-$lang-lightgreen"
                println(io, "![Language]($lang_badge)")
            end
        end

        if "description" in fields
            println(io, "")
            println(io, corpus["description"])
        end

        if "source" in fields
            println(io, "")
            println(io, "[Source]($(corpus["source"]))")
        end

        if "authors" in fields
            println(io, "")
            println(io, "### Authors")
            println(io, join(corpus["authors"], ", "))
        end

        if "subsets" in fields
            println(io, "")
            println(io, "### Subsets")
            println(io, join(corpus["subsets"], ", "))
        end

        kwargs = get_dataset_kwargs(corpus["name"])
        if ! isempty(kwargs)
            println(io, "### Keyword arguments")
            println(io, "```julia")
            println(io, kwargs)
            println(io, "```")
        end

        println(io, "\n---")
    end
end

Markdown.parse(sprint(write_corpora_docs))
```