# SpeechDatasets.jl

## Contents 

```@contents
Depth = 3
```

## Example

```julia
using SpeechDatasets
ds = dataset("Mini LibriSpeech", "path/to/minils", "minils_output")
typeof(ds[26])
```
```@example
println("Tuple{Recording, Annotation}") # hide
```

## Load a Dataset
```@docs
dataset(name::AbstractString, inputdir::AbstractString, outputdir::AbstractString)
Base.summary(dataset::SpeechDataset)
get_dataset_kwargs(name::String)

```

## Types
### SpeechDataset
```@docs
SpeechDatasetInfos
SpeechDatasetInfos(name::AbstractString)
SpeechDataset
SpeechDataset(infos::SpeechDatasetInfos, manifestroot::AbstractString, subset::AbstractString)
```
Access a single element with integer or id indexing
```julia
# ds::SpeechDataset
ds[1]
ds["1988-147956-0027"]
```
Access several elements by providing a list
```julia
ds[[1,4,7]]
ds[[8, 2, "777-126732-0015"]]
```
Get all annotations
```julia
ds.annotations
```

### Manifest items
```@docs
SpeechDatasets.ManifestItem
Recording
Annotation
AudioSources.load(r::Recording; start = -1, duration = -1, channels = r.channels)
AudioSources.load(r::Recording, a::Annotation)
SpeechDatasets.load_manifest(T::Type{<:Union{Recording, Annotation}}, path)
```

## Lexicons
```@docs
CMUDICT(path)
TIMITDICT(timitdir)
MFAFRDICT(path)
```

## Index

```@index
```